Date: 01 4, 2002 12:54:09 PM

# pnreplaceval

## Purpose

Replace the value of pnode's variable.

## Syntax

None = pnreplaceval(aPnode, varName, valString);

aPnode - type: pnode
varName - type: str

valString - type: str

None = pnreplaceval(aPnode, varName, valInteger);

aPnode - type: pnode
varName - type: str

valInteger - type: int

None = pnreplaceval(aPnode, varName, valPnode);

aPnode - type: pnode
varName - type: str

valPnode - type: pnode

None = pnreplaceval(aPnode, varName, valCon);

aPnode - type: pnode
varName - type: str

valCon - type: con

None = pnreplaceval(aPnode, varName, valPhrase);

aPnode - type: pnode
varName - type: str

valPhrase - type: phrase

None = pnreplaceval(aPnode, varName, valAttribute);

aPnode - type: pnode
varName - type: str

valAttribute - type: attr

None = pnreplaceval(aPnode, varName, valValue);

aPnode - type: pnode
varName - type: str

valValue - type: val

## Returns

## Remarks

## Example

## See Also

Parse Tree Functions